@@ -27,9 +27,9 @@
 
 #include "comicdata.h"
 
-#include <QtCore/QDate>
-
+#include <QDate>
 #include <QUrl>
+
 #include <Plasma/DataEngine>
 #include <Plasma/DataEngineConsumer>
 #include <Plasma/Applet>
@@ -67,14 +67,14 @@ class ComicApplet : public Plasma::Applet, public Plasma::DataEngineConsumer
     Q_PROPERTY(QStringList tabIdentifiers READ tabIdentifiers WRITE setTabIdentifiers NOTIFY tabIdentifiersChanged)
     Q_PROPERTY(int checkNewComicStripsInterval READ checkNewComicStripsInterval WRITE setCheckNewComicStripsInterval NOTIFY checkNewComicStripsIntervalChanged)
     Q_PROPERTY(int providerUpdateInterval READ providerUpdateInterval WRITE setProviderUpdateInterval NOTIFY providerUpdateIntervalChanged)
-    Q_PROPERTY(int maxComicLimit READ maxComicLimit WRITE setMaxComicLimit NOTIFY maxComicLimitChanged);
+    Q_PROPERTY(int maxComicLimit READ maxComicLimit WRITE setMaxComicLimit NOTIFY maxComicLimitChanged)
 
     public:
         ComicApplet( QObject *parent, const QVariantList &args );
-        ~ComicApplet();
+        ~ComicApplet() override;
 
-        void init() Q_DECL_OVERRIDE;
-        QList<QAction*> contextualActions() Q_DECL_OVERRIDE;
+        void init() override;
+        QList<QAction*> contextualActions() override;
 
         //For QML
         QObject *comicsModel() const;
@@ -156,8 +156,8 @@ Q_SIGNALS:
         void slotArchive( int archiveType, const QUrl &dest, const QString &fromIdentifier, const QString &toIdentifier );
         void slotArchiveFinished( KJob *job );
 
-    public slots:
-        void configChanged() Q_DECL_OVERRIDE;
+    public Q_SLOTS:
+        void configChanged() override;
         void saveConfig();
         Q_INVOKABLE void updateComic(const QString &identifierSuffix = QString());
         Q_INVOKABLE void goJump() { slotGoJump();}
@@ -211,7 +211,7 @@ Q_SIGNALS:
         QSizeF mLastSize;
         QSizeF mIdealSize;
         Plasma::DataEngine *mEngine;
-        QWeakPointer<KNS3::DownloadDialog> m_newStuffDialog;
+        QPointer<KNS3::DownloadDialog> m_newStuffDialog;
 
         //Tabs
         bool mTabAdded;
